pub enum GraphMutation {
Show 17 variants
UpsertNode(Node),
PatchNode {
id: NodeId,
props: Props,
},
PatchMatchingNodes {
label: Option<Label>,
props: Props,
predicates: Vec<GraphPropertyPredicate>,
patch: Props,
},
UpdateMatchingNodeProperty {
label: Option<Label>,
props: Props,
predicates: Vec<GraphPropertyPredicate>,
target_key: String,
source_key: String,
op: GraphNumericOp,
operand: Value,
},
PatchEdge {
from: NodeId,
label: Label,
to: NodeId,
id: Option<EdgeId>,
props: Props,
},
PatchMatchingEdges {
relationship: GraphRelationshipMatch,
patch: Props,
},
UpdateMatchingEdgeProperty {
relationship: GraphRelationshipMatch,
target_key: String,
source_key: String,
op: GraphNumericOp,
operand: Value,
},
RemoveNodeProps {
id: NodeId,
keys: Vec<String>,
},
RemoveMatchingNodeProps {
label: Option<Label>,
props: Props,
predicates: Vec<GraphPropertyPredicate>,
keys: Vec<String>,
},
RemoveEdgeProps {
from: NodeId,
label: Label,
to: NodeId,
id: Option<EdgeId>,
keys: Vec<String>,
},
RemoveMatchingEdgeProps {
relationship: GraphRelationshipMatch,
keys: Vec<String>,
},
DeleteMatchingNodes {
label: Option<Label>,
props: Props,
predicates: Vec<GraphPropertyPredicate>,
},
DeleteNode(NodeId),
UpsertEdge(Edge),
UpsertEdgesFromNodeMatches {
kind: GraphMutationPlanKind,
from: GraphNodeMatch,
to: GraphNodeMatch,
label: Label,
props: Props,
edge_id_policy: GraphRowEdgeIdPolicy,
},
DeleteEdge {
from: NodeId,
label: Label,
to: NodeId,
},
DeleteMatchingEdges {
relationship: GraphRelationshipMatch,
},
}Expand description
A single incremental change to a graph, for delta-oriented pipelines.
Variants
UpsertNode(Node)
PatchNode
PatchMatchingNodes
UpdateMatchingNodeProperty
PatchEdge
PatchMatchingEdges
UpdateMatchingEdgeProperty
RemoveNodeProps
RemoveMatchingNodeProps
RemoveEdgeProps
RemoveMatchingEdgeProps
DeleteMatchingNodes
DeleteNode(NodeId)
UpsertEdge(Edge)
UpsertEdgesFromNodeMatches
Fields

kind: GraphMutationPlanKind
from: GraphNodeMatch
to: GraphNodeMatch
edge_id_policy: GraphRowEdgeIdPolicyDeleteEdge
DeleteMatchingEdges
Fields

relationship: GraphRelationshipMatchTrait Implementations
Sourceimpl Clone for GraphMutation
impl Clone for GraphMutation
Sourcefn clone(&self) -> GraphMutation
fn clone(&self) -> GraphMutation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GraphMutation
impl Debug for GraphMutation
Sourceimpl<'de> Deserialize<'de> for GraphMutation
impl<'de> Deserialize<'de> for GraphMutation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<GraphMutationPlanOp> for GraphMutation
impl From<GraphMutationPlanOp> for GraphMutation
Sourcefn from(operation: GraphMutationPlanOp) -> Self
fn from(operation: GraphMutationPlanOp) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for GraphMutation
impl PartialEq for GraphMutation
Sourcefn eq(&self, other: &GraphMutation) -> bool
fn eq(&self, other: &GraphMutation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GraphMutation
impl Serialize for GraphMutation
impl StructuralPartialEq for GraphMutation