pub struct Traversal {
pub start: Start,
pub steps: Vec<Step>,
pub limit: Option<u32>,
}Fields
start: Startsteps: Vec<Step>limit: Option<u32>Implementations
Sourceimpl Traversal
impl Traversal
pub fn from_node(id: impl Into<NodeId>) -> Self
pub fn out(self, edge: impl Into<Label>) -> Self
pub fn in_(self, edge: impl Into<Label>) -> Self
pub fn both(self, edge: impl Into<Label>) -> Self
Sourcepub fn to(self, node: impl Into<Label>) -> Self
pub fn to(self, node: impl Into<Label>) -> Self
Constrains the target node label of the most recent step.
Panics
Panics if called before any step has been added with out, in_, or
both, since there is no step for the label to apply to.
pub fn limit(self, limit: u32) -> Self