pub trait CypherMutationExecutor: GraphMutationStore {
// Provided method
fn execute_cypher_mutation_plan<'life0, 'life1, 'async_trait>(
&'life0 self,
plan: &'life1 GraphMutationPlan,
) -> Pin<Box<dyn Future<Output = Result<GraphMutationReport>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait { ... }
}Expand description
Executes already-resolved Cypher/graph mutation plans.
This trait intentionally accepts GraphMutationPlan rather than Cypher
text. Parser ownership can stay with a backend or adapter until there are
enough consumers to justify a shared parser crate, while stores that
understand Grust mutation semantics can still share execution behavior.
Provided Methods
fn execute_cypher_mutation_plan<'life0, 'life1, 'async_trait>(
&'life0 self,
plan: &'life1 GraphMutationPlan,
) -> Pin<Box<dyn Future<Output = Result<GraphMutationReport>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".